CameraFrame

Struct CameraFrame 

pub struct CameraFrame {
    pub pos: DVec3,
    pub up: DVec3,
    pub facing: DVec3,
    pub scale: f64,
    pub fovy: f64,
    pub near: f64,
    pub far: f64,
    pub perspective_blend: f64,
}
The data of a camera

The CameraFrame has a CameraFrame::perspective_blend property (default is 0.0), which is used to blend between orthographic and perspective projection.

Fields

pos: DVec3

The position

up: DVec3

The up unit vec

facing: DVec3

The facing unit vec

scale: f64

The scaling factor, used in orthographic projection

fovy: f64

The field of view angle, used in perspective projection

near: f64

The near pane

far: f64

The far pane

perspective_blend: f64

The perspective blend value in [0.0, 1.0]

Implementations

Source

impl CameraFrame

pub fn new() -> Self

Create a new CameraFrame at the origin facing to the negative z-axis and use Y as up vector with default projection settings.

Source

impl CameraFrame

pub fn view_matrix(&self) -> DMat4

The view matrix of the camera

pub fn orthographic_mat(&self, frame_height: f64, aspect_ratio: f64) -> DMat4

Use the given frame size as left, right, bottom, top to construct an orthographic matrix

pub fn perspective_mat(&self, aspect_ratio: f64) -> DMat4

Use the given frame aspect ratio to construct a perspective matrix

pub fn projection_matrix(&self, frame_height: f64, aspect_ratio: f64) -> DMat4

Use the given frame size to construct projection matrix

pub fn view_projection_matrix( &self, frame_height: f64, aspect_ratio: f64, ) -> DMat4

Use the given frame size to construct view projection matrix

Source

impl CameraFrame

pub fn center_canvas_in_frame( &mut self, center: DVec3, width: f64, height: f64, up: DVec3, normal: DVec3, aspect_ratio: f64, ) -> &mut Self

Center the canvas in the frame when CameraFrame::perspective_blend is 1.0