pub struct CameraFrame {
pub pos: DVec3,
pub up: DVec3,
pub facing: DVec3,
pub scale: f64,
pub fovy: f64,
pub near: f64,
pub far: f64,
pub perspective_blend: f64,
}Expand description
The data of a camera
The CameraFrame has a CameraFrame::perspective_blend property (default is 0.0),
which is used to blend between orthographic and perspective projection.
Fields
pos: DVec3The position
up: DVec3The up unit vec
facing: DVec3The facing unit vec
scale: f64The scaling factor, used in orthographic projection
fovy: f64The field of view angle, used in perspective projection
near: f64The near pane
far: f64The far pane
perspective_blend: f64The perspective blend value in [0.0, 1.0]
Implementations
Sourceimpl CameraFrame
impl CameraFrame
Sourceimpl CameraFrame
impl CameraFrame
Sourcepub fn view_matrix(&self) -> DMat4
pub fn view_matrix(&self) -> DMat4
The view matrix of the camera
Sourcepub fn orthographic_mat(&self, frame_height: f64, aspect_ratio: f64) -> DMat4
pub fn orthographic_mat(&self, frame_height: f64, aspect_ratio: f64) -> DMat4
Use the given frame size as left, right, bottom, top to construct an orthographic matrix
Sourcepub fn perspective_mat(&self, aspect_ratio: f64) -> DMat4
pub fn perspective_mat(&self, aspect_ratio: f64) -> DMat4
Use the given frame aspect ratio to construct a perspective matrix
Sourcepub fn projection_matrix(&self, frame_height: f64, aspect_ratio: f64) -> DMat4
pub fn projection_matrix(&self, frame_height: f64, aspect_ratio: f64) -> DMat4
Use the given frame size to construct projection matrix
Sourcepub fn view_projection_matrix(
&self,
frame_height: f64,
aspect_ratio: f64,
) -> DMat4
pub fn view_projection_matrix( &self, frame_height: f64, aspect_ratio: f64, ) -> DMat4
Use the given frame size to construct view projection matrix
Sourceimpl CameraFrame
impl CameraFrame
Sourcepub fn center_canvas_in_frame(
&mut self,
center: DVec3,
width: f64,
height: f64,
up: DVec3,
normal: DVec3,
aspect_ratio: f64,
) -> &mut Self
pub fn center_canvas_in_frame( &mut self, center: DVec3, width: f64, height: f64, up: DVec3, normal: DVec3, aspect_ratio: f64, ) -> &mut Self
Center the canvas in the frame when CameraFrame::perspective_blend is 1.0